/*
  SD card datalogger
 
 This example shows how to log data from three analog sensors 
 to an SD card using the SD library.
 	
 The circuit:
 * analog sensors on analog ins 0, 1, and 2
 * SD card attached to SPI bus as follows:
 ** MOSI - pin 11
 ** MISO - pin 12
 ** CLK - pin 13
 ** CS - pin 4
 
 created  24 Nov 2010
 modified 9 Apr 2012
 by Tom Igoe
 
 This example code is in the public domain.
 	 
 */
//#include <DigitalToggle.h>
#include <SD.h>

// On the Ethernet Shield, CS is pin 4. Note that even if it's not
// used as the CS pin, the hardware CS pin (10 on most Arduino boards,
// 53 on the Mega) must be left as an output or the SD library
// functions will not work.

boolean SerialDebugEnabled = true; 


int dustPin = 0; 
int dustVal = 0; 


int delayTime = 280; 
int delayTime2 = 40; 
float offTime = 9680; 

int LEDtestPin = 6; 
const int chipSelect = 10;
int ledPower = 4; 
int buttonPin = 7; 

void setup()
{
 // Open serial communications and wait for port to open:
 pinMode(10, OUTPUT);
 pinMode(ledPower, OUTPUT); 
 pinMode(LEDtestPin, OUTPUT);
 
 pinMode(buttonPin,INPUT); 
 digitalWrite(buttonPin,HIGH); 
 
 if (SerialDebugEnabled) { 
    Serial.begin(115200);
     while (!Serial) {
      ; // wait for serial port to connect. Needed for Leonardo only
    }
 }

  if (SerialDebugEnabled) { 
      Serial.print("Initializing SD card...");
  }//end serialDebug
  
  
  
  // see if the card is present and can be initialized:
  if (!SD.begin(chipSelect)) {
    if (SerialDebugEnabled) { Serial.println("Card failed, or not present"); }
    // don't do anything more:
    return;
  }
  Serial.println("card initialized.");
  
  
}//end setup

void loop()
{
  // make a string for assembling the data to log:
  String dataString = "";

/*
  // read three sensors and append to the string:
  for (int analogPin = 0; analogPin < 3; analogPin++) {
    int sensor = analogRead(analogPin);
    dataString += String(sensor);
    if (analogPin < 2) {
      dataString += ","; 
    }
  }
  */
  
  //int analogReading = 
  dataString += String(takeDustReading()); 
  dataString += ","; 
  dataString += String(digitalRead(buttonPin)); 
  // open the file. note that only one file can be open at a time,
  // so you have to close this one before opening another.
  File dataFile = SD.open("datalog1.txt", FILE_WRITE);

  // if the file is available, write to it:
  if (dataFile) {
   if (SerialDebugEnabled) {  dataFile.println(dataString);}
   //togglePin(LEDtestPin);
    dataFile.close();
    // print to the serial port too:
    if (SerialDebugEnabled) { Serial.println(dataString);}
  }  
  // if the file isn't open, pop up an error:
  else {
    if (SerialDebugEnabled) { Serial.println("error opening datalog.txt");}
  } 
}

int takeDustReading() { 
  digitalWrite(LEDtestPin, HIGH); 
  int analogReadingDust = 0; 
  digitalWrite(ledPower,LOW); // power on the LED
  delayMicroseconds(delayTime);
  analogReadingDust=analogRead(dustPin); // read the dust value via pin 5 on the sensor
  delayMicroseconds(delayTime2);
  digitalWrite(ledPower,HIGH); // turn the LED off
  delayMicroseconds(offTime);
   
   digitalWrite(LEDtestPin, LOW); 
  delay(500);
  //Serial.println(dustVal);
  return analogReadingDust; 
}//end takeDustReading


void togglePin(int pin) { 
  
  if (digitalRead(pin) == LOW)  
    digitalWrite(pin,HIGH);  
  else if (digitalRead(pin) == HIGH) 
    digitalWrite(pin,LOW);
  
}





